importlib_metadata: Library to access the metadata for a Python package
=======================================================================

Description
-----------

This is a backport package, supplying access to the functionality of
``importlib.metadata`` including improvements added to subsequent Python versions.


License
-------

Apache Software License


Upstream Contact
----------------

- https://pypi.org/project/importlib-metadata/

- http://importlib-metadata.readthedocs.io/
